@@ -46,7 +46,7 @@ class ODOO(object):
     .. doctest::
         :options: +SKIP
 
-        >>> odoo = odoorpc.ODOO('localhost', version='8.0')
+        >>> odoo = odoorpc.ODOO('localhost', version='10.0')
 
     *Python 2:*
 
@@ -73,9 +73,10 @@ class ODOO(object):
         except ValueError:
             raise ValueError("The port must be an integer")
         try:
-            timeout = int(timeout)
+            if timeout is not None:
+                timeout = float(timeout)
         except ValueError:
-            raise ValueError("The timeout must be an integer")
+            raise ValueError("The timeout must be a float")
         self._host = host
         self._port = port
         self._protocol = protocol
@@ -152,7 +153,7 @@ class ODOO(object):
             :options: +SKIP
 
             >>> odoo.version
-            '8.0'
+            '10.0'
         """
         return self._connector.version
 
@@ -268,7 +269,7 @@ class ODOO(object):
         return data
 
     def http(self, url, data=None, headers=None):
-        """Low level method to execute raw HTPP queries.
+        """Low level method to execute raw HTTP queries.
 
         .. note::
 
@@ -281,7 +282,7 @@ class ODOO(object):
         URL parameters (with :func:`urllib.urlencode` function for simple
         parameters, or multipart/form-data structure to handle file upload).
 
-        E.g., the HTTP raw query to backup a database on `Odoo 8.0`:
+        E.g., the HTTP raw query to get the company logo on `Odoo 10.0`:
 
         .. doctest::
 
